"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initializeGitRepo = exports.checkGitVersion = void 0;
const tslib_1 = require("tslib");
const child_process_1 = require("child_process");
const default_base_1 = require("./default-base");
const output_1 = require("./output");
function checkGitVersion() {
    try {
        let gitVersionOutput = (0, child_process_1.execSync)('git --version').toString().trim();
        return gitVersionOutput.match(/[0-9]+\.[0-9]+\.+[0-9]+/)[0];
    }
    catch (_a) {
        return null;
    }
}
exports.checkGitVersion = checkGitVersion;
function initializeGitRepo(directory, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const execute = (args, ignoreErrorStream = false) => {
            const outputStream = 'ignore';
            const errorStream = ignoreErrorStream ? 'ignore' : process.stderr;
            const spawnOptions = {
                stdio: [process.stdin, outputStream, errorStream],
                shell: true,
                cwd: directory,
                env: Object.assign(Object.assign(Object.assign({}, process.env), (options.commit.name
                    ? {
                        GIT_AUTHOR_NAME: options.commit.name,
                        GIT_COMMITTER_NAME: options.commit.name,
                    }
                    : {})), (options.commit.email
                    ? {
                        GIT_AUTHOR_EMAIL: options.commit.email,
                        GIT_COMMITTER_EMAIL: options.commit.email,
                    }
                    : {})),
            };
            return new Promise((resolve, reject) => {
                (0, child_process_1.spawn)('git', args, spawnOptions).on('close', (code) => {
                    if (code === 0) {
                        resolve();
                    }
                    else {
                        reject(code);
                    }
                });
            });
        };
        const gitVersion = checkGitVersion();
        if (!gitVersion) {
            return;
        }
        const insideRepo = yield execute(['rev-parse', '--is-inside-work-tree'], true).then(() => true, () => false);
        if (insideRepo) {
            output_1.output.log({
                title: 'Directory is already under version control. Skipping initialization of git.',
            });
            return;
        }
        const defaultBase = options.defaultBase || (0, default_base_1.deduceDefaultBase)();
        const [gitMajor, gitMinor] = gitVersion.split('.');
        if (+gitMajor > 2 || (+gitMajor === 2 && +gitMinor >= 28)) {
            yield execute(['init', '-b', defaultBase]);
        }
        else {
            yield execute(['init']);
            yield execute(['checkout', '-b', defaultBase]); // Git < 2.28 doesn't support -b on git init.
        }
        yield execute(['add', '.']);
        if (options.commit) {
            const message = options.commit.message || 'initial commit';
            yield execute(['commit', `-m "${message}"`]);
        }
        output_1.output.log({
            title: 'Successfully initialized git.',
        });
    });
}
exports.initializeGitRepo = initializeGitRepo;
//# sourceMappingURL=git.js.map